==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/ListPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelContentRefreshedEventArgsDescription } from "./ListPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelContentRefreshedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ListPanelContentRefreshedEventArgsDescriptionMetadata, _super);
    function ListPanelContentRefreshedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelContentRefreshedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
            ListPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelContentRefreshedEventArgsDescriptionMetadata.c(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        if (a.g(ListPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.c = function (a) {
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
        a.u("ListPanelContentRefreshedEventArgs", function () { return new ListPanelContentRefreshedEventArgsDescription(); });
        a.t("ListPanelContentRefreshedEventArgs", ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ListPanelContentRefreshedEventArgsDescriptionMetadata, 'ListPanelContentRefreshedEventArgsDescriptionMetadata');
    ListPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ListPanelContentRefreshedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelContentRefreshedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ListPanelContentRefreshedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ListPanelContentRefreshedEventArgsDescription } from "./ListPanelContentRefreshedEventArgsDescription";
/**
 * @hidden
 */
var ListPanelContentRefreshedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ListPanelContentRefreshedEventArgsDescriptionMetadata, _super);
    function ListPanelContentRefreshedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ListPanelContentRefreshedEventArgsDescriptionMetadata.b = function (a) {
        if (ListPanelContentRefreshedEventArgsDescriptionMetadata.a == null) {
            ListPanelContentRefreshedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ListPanelContentRefreshedEventArgsDescriptionMetadata.c(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ListPanelContentRefreshedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.c = function (a) {
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.d = function (a) {
        ListPanelContentRefreshedEventArgsDescriptionMetadata.b(a);
        a.aa("ListPanelContentRefreshedEventArgs", function () { return new ListPanelContentRefreshedEventArgsDescription(); });
        a.z("ListPanelContentRefreshedEventArgs", ListPanelContentRefreshedEventArgsDescriptionMetadata.a);
    };
    ListPanelContentRefreshedEventArgsDescriptionMetadata.$t = markType(ListPanelContentRefreshedEventArgsDescriptionMetadata, 'ListPanelContentRefreshedEventArgsDescriptionMetadata');
    ListPanelContentRefreshedEventArgsDescriptionMetadata.a = null;
    return ListPanelContentRefreshedEventArgsDescriptionMetadata;
}(Base));
export { ListPanelContentRefreshedEventArgsDescriptionMetadata };
